==> kpicosim-trinity_3.5.13.2.orig.tar.xz: kpicosim-trinity-3.5.13.2/src/kscratchpadview.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Mark Six                                        *
 *   marksix@xs4all.nl                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/
#ifndef KSCRATCHPADVIEW_H
#define KSCRATCHPADVIEW_H

#include <ktoolbar.h>
#include <ktextedit.h>

class KScratchpadView : public KToolBar
{
	Q_OBJECT
  TQ_OBJECT
	public:
    	KScratchpadView(TQWidget *parent = 0, const char *name = 0);
    	~KScratchpadView();
		
		void setContent( unsigned char *values, unsigned int len ) ;
		
	protected:
		KTextEdit	* view ;
};

#endif

==> kpicosim-trinity-14.1.0.tar.xz: kpicosim-trinity-14.1.0/src/kscratchpadview.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Mark Six                                        *
 *   marksix@xs4all.nl                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/
#ifndef KSCRATCHPADVIEW_H
#define KSCRATCHPADVIEW_H

#include <tdetoolbar.h>
#include <ktextedit.h>

class KScratchpadView : public TDEToolBar
{
	Q_OBJECT
  
	public:
    	KScratchpadView(TQWidget *parent = 0, const char *name = 0);
    	~KScratchpadView();
		
		void setContent( unsigned char *values, unsigned int len ) ;
		
	protected:
		KTextEdit	* view ;
};

#endif
